==> R2PPT_1.0.tar.gz: R2PPT/man/PPT.AddTitleSlide.Rd <==
\name{PPT.AddTitleSlide}
\alias{PPT.AddTitleSlide}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Add a title slide to current PowerPoint presentation}
\description{
Adds a slide to the current PowerPoint presentation of Microsoft type 'ppLayoutTitle'.
}
\usage{
PPT.AddTitleSlide(ppt, title = NULL, subtitle = NULL, title.font = NULL, title.fontsize = NULL, subtitle.font = NULL, subtitle.fontsize = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{ppt}{Required list of objects of class 'COMobject' as initialised by PPT.Init. See example.}
\item{title}{Optional title text.}
\item{subtitle}{Optional subtitle text.}
\item{title.font}{Optional character title font.}
\item{title.fontsize}{Optional numeric title font size.}
\item{subtitle.font}{Optional character subtitle font.}
\item{subtitle.fontsize}{Optional numeric subtitle font size.}

}
%\details{}
\value{

  \item{ppt }{Invisibly returns an updated list of objects of class 'COMobject'.}
  
}
\references{ 
See \url{ http://sunsite.univie.ac.at/rcom} for more details on rcom.

}
\author{ Wayne Jones \email{wayne_betws@hotmail.com}}
\section{Warning}{You must update the list of ComObjects initialised with PPT.Init when you call this function. See the example. }
%\note{}
\seealso{\code{\link{PPT.Init}},\code{\link{PPT.AddTitleSlide}},\code{\link{PPT.AddTextSlide}},\code{\link{PPT.AddTitleOnlySlide}},\code{\link{PPT.Present}},\code{\link{PPT.ApplyTemplate}},\code{\link{PPT.AddGraphicstoSlide}}}


\examples{

\dontrun{
myPres<-PPT.Init(visible=TRUE)
myPres<-PPT.AddBlankSlide(myPres)
myPres<-PPT.AddTitleSlide(myPres,title="Title Slide",subtitle="Subtitle here")
myPres<-PPT.AddTitleOnlySlide(myPres,title="Title Only",title.fontsize=40,title.font="Arial")
myPres<-PPT.AddTextSlide(myPres,title="Text Slide",text="Text1 \rText2 \rText3",text.font="Arial")
rm(myPres)
} 

}
\keyword{IO}
\keyword{connection}

==> R2PPT_2.0.tar.gz: R2PPT/man/PPT.AddTitleSlide.Rd <==
\name{PPT.AddTitleSlide}
\alias{PPT.AddTitleSlide}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Add a title slide to current PowerPoint presentation}
\description{
Adds a slide to the current PowerPoint presentation of Microsoft type 'ppLayoutTitle'.
}
\usage{
PPT.AddTitleSlide(ppt, title = NULL, subtitle = NULL, title.font = NULL, title.fontsize = NULL, subtitle.font = NULL, subtitle.fontsize = NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
\item{ppt}{Required list of COM objects as initialised by PPT.Init. See example.}
\item{title}{Optional title text.}
\item{subtitle}{Optional subtitle text.}
\item{title.font}{Optional character title font.}
\item{title.fontsize}{Optional numeric title font size.}
\item{subtitle.font}{Optional character subtitle font.}
\item{subtitle.fontsize}{Optional numeric subtitle font size.}

}
%\details{}
\value{

  \item{ppt}{Invisibly returns a list of COM objects. 
%of class 'COMobject'.
}
  
}
\references{ 
See \url{ http://sunsite.univie.ac.at/rcom} for more details on rcom and \url{http://www.omegahat.org/RDCOMClient/} for more details on RDCOMClient.
}

\author{ Wayne Jones \email{'wayne_betws@hotmail.com'}}
\section{Warning}{You must save the returned list of COM objects initialised with PPT.Init to an R object. See the example. }
%\note{}
\seealso{\code{\link{PPT.Init}},\code{\link{PPT.AddTitleSlide}},\code{\link{PPT.AddTextSlide}},\cr
\code{\link{PPT.AddTitleOnlySlide}},\code{\link{PPT.Present}},\code{\link{PPT.ApplyTemplate}},\code{\link{PPT.AddGraphicstoSlide}}}


\examples{

\dontrun{
myPres<-PPT.Init() 
#or 
#myPres<-PPT.Init(method="RDCOMClient")
myPres<-PPT.AddBlankSlide(myPres)
myPres<-PPT.AddTitleSlide(myPres,title="Title Slide",subtitle="Subtitle here")
myPres<-PPT.AddTitleOnlySlide(myPres,title="Title Only",title.fontsize=40,title.font="Arial")
myPres<-PPT.AddTextSlide(myPres,title="Text Slide",text="Text1 \rText2 \rText3",text.font="Arial")
rm(myPres)
} 

}
\keyword{IO}
\keyword{connection}
